Index: trunk/src/tmcsim/utilities/BuildHighwayFile.java
===================================================================
--- trunk/src/tmcsim/utilities/BuildHighwayFile.java	(revision 274)
+++ trunk/src/tmcsim/utilities/BuildHighwayFile.java	(revision 276)
@@ -42,6 +42,7 @@
     /** A dictionary to lookup VDS data given vdsID */
     Map<String,VehicleDetectionStation> vdsDict;
-    /** A list of ignored VDS id's - FOR DEBUGGING*/
-    List<String> ignored = new ArrayList<String>();
+    /** A list of used VDS ids - FOR DEBUGGING*/
+    Set<String> vdsUsed = new HashSet<String>();
+    int ignored = 0; // count of ignored VDS ids
     /** Reported missing */
     Set<String> missingVDS = new HashSet<String>();
@@ -149,4 +150,5 @@
                 {
                     vdsDict.get(vdsID).addLane(laneDesc);
+                    vdsUsed.add(vdsID);
                 }
                 else
@@ -169,5 +171,5 @@
                     if (!missingLDS.contains(ldsID))
                     {
-                        System.out.println("missing ldsID in Station Addr lookup: "+ldsID);
+                        System.out.println("missing ldsID in Station Addr lookup: "+ldsID+" "+ String.format("%3s %s %5s",fwy,dir,postmile));
                         missingLDS.add(ldsID);
                     }
@@ -228,6 +230,4 @@
             Scanner vdsScanner = new Scanner(new File(filepath+vdsFileName));
             
-            System.out.println(vdsScanner.nextLine()); // echo col headers
-
             // Read the tab-delimited vds file
             while(vdsScanner.hasNextLine())
@@ -243,10 +243,10 @@
                 else
                 {
-                    ignored.add(vds.id);
+                    ignored++;
                 }
                 lineScanner.close();
             }
             vdsScanner.close();
-            System.out.println("Ignored "+ignored.size() + " non-Mainline VDS's");
+            System.out.println("Ignored "+ignored+ " non-Mainline VDS's");
             
         } catch (FileNotFoundException ex)
@@ -289,4 +289,19 @@
     }
 
+    /** Display the set of VDS in the dict that didn't get used (weren't found
+     * in loop file.
+     */
+    private void showLeftoverVDS()
+    {
+        Set<String> vdsItems = vdsDict.keySet(); // get all the VDS ids
+        vdsItems.removeAll(vdsUsed); // remove the ones that were used
+        System.out.println("Here are the unused VDS ids:");
+        // list the remaining items
+        for (String vdsitem: vdsItems)
+        {
+            System.out.print(vdsitem+"  ");
+        }
+        System.out.println("");            
+    }
     /**
      * @param args the command line arguments
@@ -299,4 +314,6 @@
         app.createLanelookup();
         app.createHighwayFile();
+        app.showLeftoverVDS();
+        System.out.println("Build complete, output file: "+highwayFile);
     }
 
